==> objection-1.0.6.tar.gz: objection-1.0.6/objection/hooks/android/hooking/dump-arguments.js <==
// Watches a Java class method and dumps the calling arguments.
// All of the matching overloads of the method in question
// is also watched.

var target_class = Java.use('{{ target_class }}');
var target_method = '{{ target_method }}';
var overload_count = eval('target_class.{{ target_method }}.overloads.length');

send(JSON.stringify({
    status: 'success',
    error_reason: NaN,
    type: 'java-argument-dump',
    data: 'Found class with ' + overload_count + ' overloads for {{ target_method }}'
}));

// Hook all of the overloads found for this class.method
for (var i = 0; i < overload_count; i++) {

    send(JSON.stringify({
        status: 'success',
        error_reason: NaN,
        type: 'java-argument-dump',
        data: 'Hooking overload ' + (i + 1)
    }));

    // Hook the overload.
    eval('target_class.{{ target_method }}.overloads[i]').implementation = function () {

        send(JSON.stringify({
            status: 'success',
            error_reason: NaN,
            type: 'java-argument-dump',
            data: 'Called {{ target_class }}.{{ target_method }} (args: ' + arguments.length + ')'
        }));

        // Loop the arguments and dump the values.toString()
        for (var h = 0; h < arguments.length; h++) {

            send(JSON.stringify({
                status: 'success',
                error_reason: NaN,
                type: 'java-argument-dump',
                data: '{{ target_method }} - Arg ' + h +  ': ' + arguments[h].toString(),
            }));
        }

        // continue with the original method
        eval('this.{{ target_method }}.apply(this, arguments)');
    }
}

==> objection-1.1.4.tar.gz: objection-1.1.4/objection/hooks/android/hooking/dump-arguments.js <==
// Watches a Java class method and dumps the calling arguments.
// All of the matching overloads of the method in question
// is also watched.

var target_class = Java.use('{{ target_class }}');
var overload_count = eval('target_class.{{ target_method }}.overloads.length');

send(JSON.stringify({
    status: 'success',
    error_reason: NaN,
    type: 'java-argument-dump',
    data: 'Found class with ' + overload_count + ' overloads for {{ target_method }}'
}));

// Hook all of the overloads found for this class.method
for (var i = 0; i < overload_count; i++) {

    send(JSON.stringify({
        status: 'success',
        error_reason: NaN,
        type: 'java-argument-dump',
        data: 'Hooking overload ' + (i + 1)
    }));

    // Hook the overload.
    eval('target_class.{{ target_method }}.overloads[i]').implementation = function () {

        send(JSON.stringify({
            status: 'success',
            error_reason: NaN,
            type: 'java-argument-dump',
            data: 'Called {{ target_class }}.{{ target_method }} (args: ' + arguments.length + ')'
        }));

        // Loop the arguments and dump the values.toString()
        for (var h = 0; h < arguments.length; h++) {

            send(JSON.stringify({
                status: 'success',
                error_reason: NaN,
                type: 'java-argument-dump',
                data: '{{ target_method }} - Arg ' + h +  ': ' + arguments[h].toString()
            }));
        }

        // continue with the original method
        eval('this.{{ target_method }}.apply(this, arguments)');
    }
}
